#' Get Ngram Count per Year for National Library Book Collection
#'
#' This function queries the National Library's book collection API to retrieve
#' the ngram count per year for the specified parameters. It can be used to plot
#' an ngram based on the words' presence in books in the library's collection.
#'
#' @param city (character, optional) The city of publication. Default is NULL.
#' @param ddk (character, optional) The Dewey Decimal Classification (DDC) code. Default is NULL.
#' @param lang (character, optional) The language code of the books. Default is NULL.
#' @param period (list, optional) A list containing the start and end years of the period to search. Default is an empty list.
#' @param publisher (character, optional) The publisher's name. Default is NULL.
#' @param title (character, optional) The title or a part of the title of the books. Default is NULL.
#' @param topic (character, optional) A topic or subject associated with the books. Default is NULL.
#' @param word (list, optional) A list of words (ngrams) to search for in the books. Default is list("hus", "blokk").
#'
#' @return A data frame with the ngram count per year for the specified parameters.
#' @export
#'
#' @importFrom utils stack
#'
#' @examples
#' # Get ngram count for the words "hus" and "blokk" in the specified period
#' get_ngram_from_books(period = list(1990, 2000))
#'
#' # Get ngram count for the word "library" in English books
#' get_ngram_from_books(lang = "eng", word = list("library"))
get_ngram_from_books <- function(city = NULL, ddk = NULL, lang = NULL, period = list(), publisher = NULL, title = NULL, topic = NULL, word = list("hus", "blokk")){

  ngram_book <- "https://api.nb.no/dhlab/ngram_book"

  params <- list("city" = city, "ddk" = ddk, "lang" = lang, "period" = period, "publisher" = publisher, "title" = title, "topic" = topic, "word" = word)
  query <- POST(ngram_book, body = params, encode = "json")

  return(stack(content(query)))
}
